#
# spec file for package kdenlive
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mlt_version 7.14.0
%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kdenlive
Version:        25.04.2
Release:        1.1
Summary:        Non-linear video editor
License:        GPL-3.0-or-later
URL:            https://www.kdenlive.org/
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  rttr-devel
BuildRequires:  shared-mime-info
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_version}
BuildRequires:  cmake(KF6Codecs) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6FileMetaData) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6NotifyConfig) >= %{kf6_version}
BuildRequires:  cmake(KF6Purpose) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(OpenTimelineIO)
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6NetworkAuth) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6SvgWidgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(Imath)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(mlt++-7) >= %{mlt_version}
BuildRequires:  pkgconfig(mlt-framework-7) >= %{mlt_version}
BuildRequires:  pkgconfig(x11)
Requires:       libmlt7-module-qt6
Requires:       melt >= 7
# Required at runtime
Requires:       kf6-qqc2-desktop-style >= %{kf6_version}
Requires:       qt6-declarative-imports >= %{qt6_version}
# No stable release yet
# Recommends:     glaxnimate
# Required by the composition and effects panel
Requires:       kf6-knewstuff-imports >= %{kf6_version}
Recommends:     %{_bindir}/dvdauthor
Recommends:     %{_bindir}/dvgrab
Recommends:     %{_bindir}/ffmpeg
Recommends:     %{_bindir}/ffplay
Recommends:     %{_bindir}/genisoimage
Recommends:     %{_bindir}/mediainfo
Recommends:     frei0r-plugins
Recommends:     libv4l
Obsoletes:      kdenlive5 < %{version}
Provides:       kdenlive5 = %{version}

%description
Kdenlive is a non-linear video editor for GNU/Linux and FreeBSD, which supports
DV, AVCHD (experimental support) and HDV editing. Kdenlive relies on several
other open source projects, such as FFmpeg and the MLT video framework. It was
designed to answer all needs, from basic video editing to semi-professional
work.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DFETCH_OTIO:BOOL=FALSE

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --with-man --all-name

%fdupes -s %{buildroot}

# Already packaged with %%doc
rm -r %{buildroot}%{_datadir}/doc/Kdenlive

%files
%license LICENSES/*
%doc AUTHORS README.md
%doc %lang(en) %{_kf6_htmldir}/en/kdenlive/
%dir %{_kf6_plugindir}/kf6/thumbcreator
%{_kf6_applicationsdir}/org.kde.kdenlive.desktop
%{_kf6_appstreamdir}/org.kde.kdenlive.appdata.xml
%{_kf6_bindir}/kdenlive
%{_kf6_bindir}/kdenlive_render
%{_kf6_configkcfgdir}/kdenlivesettings.kcfg
%{_kf6_debugdir}/kdenlive.categories
%{_kf6_iconsdir}/hicolor/*/*/*
%{_kf6_knsrcfilesdir}/kdenlive_effects.knsrc
%{_kf6_knsrcfilesdir}/kdenlive_keyboardschemes.knsrc
%{_kf6_knsrcfilesdir}/kdenlive_luts.knsrc
%{_kf6_knsrcfilesdir}/kdenlive_renderprofiles.knsrc
%{_kf6_knsrcfilesdir}/kdenlive_titles.knsrc
%{_kf6_knsrcfilesdir}/kdenlive_wipes.knsrc
%{_kf6_mandir}/man1/kdenlive.1%{ext_man}
%{_kf6_mandir}/man1/kdenlive_render.1%{ext_man}
%{_kf6_notificationsdir}/kdenlive.notifyrc
%{_kf6_plugindir}/kf6/thumbcreator/mltpreview.so
%{_kf6_sharedir}/kdenlive/
%{_kf6_sharedir}/mime/packages/org.kde.kdenlive.xml
%{_kf6_sharedir}/mime/packages/westley.xml

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/kdenlive/

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- Changes since 25.04.1:
  * Fix moving subtitle with grab (kde#474193)
  * Fix empty gradient in config causes crash (kde#505014)
  * Backport missing effects xml
  * Fix quick markers not taking clip crop in in timeline
  * Fix marker dialog not allowing to add marker if only 1 category exists (kde#504993)
  * Fix merge error causing freeze on exit
  * Fix crash in HistogramGenerator when running on a white color clip
  * Fix whisper model dir not being created if asked to do so
  * Fix canceling quit on rendering leaves kdenlive in unstable state
  * Only clear undo stack when we delete a timeline sequence, not a standard bin clip
  * Fix misalignment of monitor tools
  * Fix OTIO path issue on import (kde#504708)
  * Fix bin clip effects disappear after disabling a timeline clip (kde#439194)
  * Fix keyframe in monitor not correctly reported on clip selection
  * Fix monitor scene not correcty activated on clip selection
  * Fix small error causing offset in long audio thumbnails
  * Fix guides list buttons not working on app opening
  * Fix built-in effects disabled state changes on cut
  * Fix render widget target file can have no extension or incorrect path.
  * SAM2: show message and full log if the python script crashes, try to auto reinstall if the venv python exe is missing
  * Save and restore titler tool panel width
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- Too many changes since 25.04.0, only listing bugfixes:
  * Fix crash moving single clip from group and standalone clip (kde#503626)
  * Fix ghost widget and other layout issues in effectstack (kde#503562)
  * Fix project corruption pasting sequences into another project (kde#503227)
  * Fix title text outline has sharp angles Requires latest MLT git (kde#437781)
  * Fix editing title text with outline makes text ugly (kde#503205)
  * Audio mix composition should only be allowed on audio tracks (kde#502998)
  * Don't save disabled built-in effects when saving effect stack (kde#502973)
  * Fix freeze extracting last clips in timeline (kde#503149)
* Tue Apr 15 2025 Atri Bhattacharya <badshah400@gmail.com>
- Drop BuildRequires: pkgconfig(glew) as it is not used for build
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- Too many changes since 25.03.90, only listing bugfixes:
  * Show proper error message when trying to apply a mix and all tracks are disabled (kde#502610)
  * Fix Extract clip with multiple selection (kde#485517)
  * Fix documentation link to JogShuttle (kde#502618)
  * Fix timeline audio thumbnails for clips with multiple streams and different channel count (kde#501280)
  * Make Remove timeline preview work with undo/redo (kde#502192)
  * Fix clear history broken BUG: 499544 FIXED-IN: 25.04.0 (kde#499544)
  * Fix glaxnimate connection not terminated on app close on Windows (kde#473036)
  * Text based edit: with multiple text selection, create multiple markers (kde#498259)
  * Better default height for assets info box, remember its size (kde#502089)
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Too many changes since 24.12.3, only listing bugfixes:
  * Correclty restore all audio streams in restore audio operation. Also, we should use active tracks not audio target tracks to restore (kde#474140)
  * When opening a project file with a custom effect that is not on the system, use the MLT base effect to correctly recover the project (kde#460928)
  * Remove unsupported html tags from notifications (kde#174560)
  * Fix speed dialog mnemonics and tab order (kde#501565)
  * Fix profile change aborted when switching from empty project (kde#500751)
  * Insert space should move guides if they are not locked (kde#500773)
  * Add keyboard shortut for render filename field (kde#500772)
  * Fix rendering files with an ampersand in name is broken on linux (kde#500794)
  * Fix saved tracker effect doesn't work (kde#501227)
  * Fix replacing color clip (kde#501394)
  * Fix transcoding and proxying of clips with cover art (kde#496599)
  * Fix effects with analysis step like loudness 2 pass and tracker broken on cut clips or on tracks (kde#492729)
  * Ensure proxy clips have a fixed frame rate (using vsync 1) (kde#499559)
  * Fix incorrect behavior / crash on single item deletion (kde#499570)
  * Fix crash trying to import invalid keyframe data from clipboard (kde#499531)
  * Fix crash setting empty name for folder (kde#499070)
  * Better fix for expand library clips broken with proxies (kde#499171)
  * Fix effects layout broken on resize (kde#498749)
  * Reassemble proxy profile elements in the correct order after validation (kde#485356)
  * Fix the spinbox range for title position and size (kde#487950)
  * Ensure sequence clips in timeline are not resized to smaller when hiding a track (kde#498178)
  * Fix crash saving effect stack (kde#498124)
  * Fix reload or proxy clip losing tags, markers, force aspect ratio (kde#498014)
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * Fix audio playback breaks when switching between bin clips
  * Fix crash on single item deletion in group
  * Fix crash pasting clips with a same track transition (like dissolve)
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Don't try to update monitor overlay if effect is disabled
  * Fix crash setting empty name for folder (kde#499070)
  * Better fix for expand library clips broken with proxies (kde#499171)
  * Try to fix Whisper models folder on Flatpak
  * Don't try to delete ui file elements on subtitlemanager close
  * Fix effect stack widget not properly resizing. Related to #1957
  * Ensure built-in effects reset button is enabled
  * Ensure vidstab external files are correctly listed and archived
  * Added 2 decimals for the rotation parameter (addresses bug #498586)
  * Rescale 48-apps-kdenlive.png to 48x48
  * Fix effects layout broken on resize (kde#498749)
  * Fix possible crash on exit
  * Reassemble proxy profile elements in the correct order after validation (kde#485356)
  * Fix the spinbox range for title position and size (kde#487950)
  * Fix rendering progress not shown when rendering a zone
  * Fix FFmpeg for STT not found on Mac (kde#498949)
  * Backport fix for invalid file names in custom effects (kde#498710)
  * Nightly Flatpak: remove movit dependency
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Ensure sequence clips in timeline are not resized to smaller when hiding a track (kde#498178)
  * Fix crash moving build-in effect with feature disabled
  * Fix crash saving effect stack (kde#498124)
  * Fix layout order with > 9 layouts
  * Fix use after free from last commit
  * Fix reload or proxy clip losing tags, markers, force aspect ratio (kde#498014)
  * Fix bin clips effects sometimes incorrectly applied to timeline instance
  * Fix typo BUG: 497932 (kde#497932)
  * Fix title widget braking text shadow and typewriter settings. (kde#476885)
  * Math operators not supported in xml params (kde#497796)
  * Fix track resizing
  * Fix bin effects cannot be removed from timeline instance
  * Fix crash trying to move bin effect before builtin effect
  * Fix venv packages install on some distros
  * Fix Whisper models download
  * Fix delta display when resizing clip, add duration info when resizing from start
  * Fix line return when pasting text with timecodes inside project notes
  * Fix transparent rendering ffv1 profile
  * Bring back presets to build in effects
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- Changes since 24.11.90:
  * Save extracted frames in project folder is project is supposed to save files in its parent folder (kde#496486)
  * Fix proxied image messes exif orentation (kde#496681)
  * Fix audio capture, ensure default monitor scene is active to start recording
  * Don't allow question mark in script names (not supported by MLT) (kde#496763)
  * Fix motion tracker effect link to documentation and create models folder in any case to avoid error message
  * Allow creating 1 frame mixes
  * Fix resizing mix to 1 frame duration breaking mix position
  * Move enable builtin effects from asset panel to Kdenlive Settings dialog
  * Various built in effect fixes on copy effect
  * Properly display the full log on missing render file
  * Ensure we display an error if the render job finishes but rendered file does not exist
  * Don't enable keyframes in timeline if an effect is disabled
  * Disable keep original size feature as it has issues (causes distortion if another transform is added in timeline)
  * Archiving: don't show two abort buttons
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Too many changes since 24.11.80, only listing bugfixes:
  * Don't change timeline audio/video targets while dragging (kde#496354)
  * Fix crash trying to remove keyframes when there are none (kde#496391)
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Too many changes since 24.08.3, only listing bugfixes:
  * fix resetting Help shortcuts on each application launch (kde#495373)
  * Fix title producer update on edit undo (kde#494142)
  * Fix scolling timeline with rubberband or when dragging from file manager can move last selected clip in timeline (kde#492635)
  * Fix adding marker from project notes always adds it at 00:00 (kde#492697)
  * Fix MLT lumas not correctly recognized by archive feature (kde#492435)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * Fix crash caused by incorrect codec passed on opening subtitle (kde#495410)
  * Fix shadowed variable causing incorrect clip removal on project opening
  * Fix qml crash building timeline with Qt 6.8
  * Fix generate proxy when frame size is above a value not using the current project setting
  * Fix shadow variable causing clip removal on project opening
  * Fix monitor seek to prev/next keyframe not working in rotoscoping
  * Fix missing build-in LUT files not correctly fixed on project open
  * Fix clip jobs like stabilize creating invalid folders
  * Fix freeze loading project with invalid folder id
  * Don't invalidate timeline preview when replacing an audio clip in bin
  * Ensure monitor is cleared and ruler hidden when no clip or a folder is selected in bin
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- Changes since 24.08.1:
  * Fix title producer update on edit undo (kde#494142)
  * Fix typo in dance.xml
  * Fix single item(s) move
  * Fix cycle effects playling timeline and sometimes broken after reopening project Fixes #1921
  * Fix recent regression breaking all sort of things when opening projects. Related to #1925
  * Fix crash when dragging clip and using mouse wheel
  * Don't play when clicking monitor container if disabled in settings
  * Fix effect zones lost on project reopening
  * Various fixes for bin clip effects
  * disable check for ghost effects that currently removes valid effects
  * detect and fix track producers with incorrect effects
  * fix bin effects sometimes not correctly removed from timeline instance
  * Don't try to build clone effect it if does not apply to the target
  * Don't unnecessarily check MLT tractors
  * Fix crash opening file with missing clips
  * Fix crash on project close
  * snapcraft: Remove glaximate option, it is not needed here.
  * snspcraft: Release from release branch.
  * Fix compilation
  * Fix possible crash opening an interlaced project
  * Fix on monitor seek to next/previous keyframe buttons
  * Fix crash editing keyframes in a bin clip with grouped effects enabled
  * Don't try to connect to dbus jobview on command line rendering
  * Fix Qt5 compilation
  * FIx looping through clips in project monitor effect scene
  * Fix loop selected clip Fixes #1915
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * Fix reassigning timecode to project clip (kde#492697)
  * Fix possible crash on undo/redo single selection move
  * Fix dragging transitions to a clip cut to create a mix
  * Fix multiple selection broken
  * Fix clip offset not appearing on selection in timeline
  * Ensure bin clips with effects disabled keep their effects disabled when added to a new sequence
  * Fix keyframe at last frame prevents resizing clip on high zoom
  * Fix effects/compositions list size (kde#492586)
  * Fix compositions cannot be easily selected in timeline
  * Replace : and ? chars in guides names for rendering
  * Don't trigger timeline scroll when mouse exits timeline on a clip drag, it caused incorrect droppings and ghost clips.
  * Fix scolling timeline with rubberband or when dragging from file manager can move last selected clip in timeline (kde#492635)
  * Fix adding marker from project notes always adds it at 00:00 (kde#492697)
  * fix blurry widgets on high DPI displays
  * Fix keyframe param not correctly enabled on first keyframe click
  * Fix curveeditor crash on empty track
  * Ensure rendering with separate file for each audio track keeps the correct audio tag in the file name
  * Fix render project folder sometimes lost, add proper enums instead of unreadable ints
  * Fix MLT lumas not correctly recognized by archive feature (kde#492435)
  * Fix configure toolbars messing UI layout
  * Effects List: ensure deprecated category is always listed last
  * Fix tabulations in Titler (requires latest MLT git)
  * Titler: ensure only plain text can be pasted, prepare support for tabulations (needs MLT patch)
  * Don't accept empty whisper device
  * Fix ffmpeg path for Whisper on Mac
  * Fix archive doesn't save the video assets when run multiple times
  * Fix document notes timecode links may be broken after project reload
  * Fix broken qml font on AppImage
  * Remove incorrect taskmanager unlock
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes since 24.05.2, only listing bugfixes:
  * Fix some effect names not translated (kde#491438)
  * Fix titler background is pixelated (kde#431606)
  * Fix timeline scrolling down by a few pixels when already at the bottom when using rubberband or spacer (kde#490956)
  * Fix crash pasting single selected clip (kde#490370)
  * Fix color theme menu not showing active theme (kde#489958)
  * Fix cannot restore audio after saving project with master muted (kde#489985)
  * Fix crash trying to save effect with slash in name (kde#487224)
  * Fix wrong FFmpeg chapter export TIMEBASE (kde#487019)
  * JogShuttle, add note and link for installation on Windows (kde#485602)
* Wed Jul 24 2024 Christophe Marin <christophe@krop.fr>
- Add kf6-qqc2-desktop-style runtime dependency (boo#1228273)
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- Changes since 24.05.1:
  * Fix guides categories not correctly saved in document (kde#489079)
  * Fix adding record track adds a normal audio track (kde#489080)
  * Fix rendering with aspect ratio change always renders with proxies Fixes #1883
  * Fix compilation on Windows with KF 6.3.0
  * Fix timeline duration not correctly updated, resulting in audio/video freeze in timeline after 5 min Related to #1885
  * Fix Windows build without DBUS
  * Fix crash on spacer tool with subtitles Related to #1627
- Drop patch, merged upstream:
  * 0001-Fix-timeline-duration-not-correctly-updated-resultin.patch
* Thu Jun 20 2024 Christophe Marin <christophe@krop.fr>
- Add upstream fix (kde#488689):
  * 0001-Fix-timeline-duration-not-correctly-updated-resultin.patch
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Don't try renaming sequence on double click in empty area of
    timeline tab bar
  * Fix deletion of wrong effect wihh multiple instances of an
    effect and group effects enabled
  * Fix single selected clip disappearing from timeline when
    dragging a new clip in timeline
  * [cmd rendering] Ensure proper kdenlive_render path for AppImage
  * Fix freeze/crash on undo/redo track insertion
  * Fix crash on undo/redo multiple track insertion
  * Project settings: don't list embedded title clips as empty
    files in the project files tab
  * Fix undo move effect up/down. On effect move, also move the
    active index, increase margins between effects Related to #1786
  * Fix removing a composition from favorites
  * Properly activate effect when added to a timeline clip
  * Fix spacer tool can move backwards and overlap existing clips Fixes #1879
  * Fix crash deleting subtitle when the file url was selected. (kde#487872)
  * Fix possible crash on project opening
  * Fix extra dash added to custom clip job output
  * Fix usage of QUrl for LUT lists
  * Fix default keyframe type referencing the old deprecated smooth type
  * Be more clever splitting custom ffmpeg commands around quotes
  * Fix effect name focus in save effect
  * Fix tests
  * fix selection when cutting an unselected clip under mouse
  * Fix loading timeline clip with disabled stack should be
    disabled Create undo entry when disabling clip effect stack
  * Fix crash trying to save effect with slash in name (kde#487224)
  * Remove quotes in custom clip jobe, fix progress display
  * Fix setting sequence thumbnail from clip monitor
  * Fix locked track items don't have red background on project open
  * Fix spacer tool doing fake moves with clips in locked tracks
  * Hide timeline clip status tooltip when mouse leaves
- Drop patch, merged upstream:
  * 0001-Fix-build-when-using-GLES.patch
* Tue May 28 2024 Christophe Marin <christophe@krop.fr>
- Add fix for ARM builds (kde#483425)
  * 0001-Fix-build-when-using-GLES.patch
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Too many changes since 24.04.80, only listing bugfixes:
  * Fix sequence clip inserted in another one is not updated if track is locked. (kde#487065)
  * Fix duplicating sequence clips (kde#486855)
  * Fix wrong FFmpeg chapter export TIMEBASE (kde#487019)
  * Fix duplicating Bin clip does not suplicate effects (kde#463399)
  * Fix Ctrl+Wheel not working on some effect parameters (kde#486233)
  * Fix crash disabling sequence clip in timeline (kde#486117)
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Fix effects cannot be enabled after saving with disable bin/timeline effects Faster project opening for multi-timeline projects (kde#438970)
  * Monitor: add play zone from cursor (kde#484103)
  * fix: cannot revert letter spacing to 0 in title clips (kde#483710)
  * Block Qt5 MLT plugins in thumbnailer when building with Qt6. (kde#482335)
  * Allow customizing camcorder proxy profiles (kde#481836)
* Wed Apr 17 2024 Christophe Marin <christophe@krop.fr>
- Require the Qt6 MLT modules (boo#1222915)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Too many changes since 24.02.1, only listing bugfixes:
  * When copy/paste effects from a group, only paste effects for the active clip (kde#421667)
  * Fix: don't propose existing name for new sequence (kde#472753)
  * Fix: cannot translate the "P" for Proxy in timeline (kde#471850)
  * Fix white background and blank monitor on Windows after going back from fullscreen (kde#484081)
  * Fix: cannot move compositions properly in timeline with Qt6 (kde#484062)
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Too many changes since 24.02.0, only listing bugfixes:
  * Fix: some sequence properties incorrectly saved, like subtitles list, timeline (kde#483516)
  * Fix: Windows crash clicking fullscreen button(kde#483441)
  * fix: cannot revert letter spacing to 0 in title clips (kde#483710)
  * fix: Fix pan timeline with middle mouse button (kde#483244)
  * Fix multiple subtitles issues: several tracks not correctly saved, sequence copy not suplicating subs, crash on adding new subtitle track (kde#482434)
  * On sequence change, recursively update each sequence that embedded it (kde#482949)
  * Fix crash on spacer tool with grouped subtitle (kde#482510)
  * Block Qt5 MLT plugins in thumbnailer when building with Qt6. (kde#482335)
  * Fix crash on invalid gradient data. (kde#482134)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Too many changes since 24.01.95, only listing bugfixes:
  * Subtitles: add session id to tmp files to ensure 2 concurrent versions of a project don't share the same tmp files (kde#481525)
  * Refactor mouse position in the timeline to fix multiple small bugs (kde#480977)
  * Fix Qt6 dragging clips with subtitle track visible (kde#480829)
  * Multi guides export: replace slash and backslash in section names to fix rendering (kde#480845)
  * Fix sequence corruption on project load (kde#480776)
  * Ensure closed timeline sequences have a transparent background on opening (kde#480734)
  * Fix duplicated filenames or multiple uses not correctly handled in archiving (kde#421567, kde#456346)
  * Fix multiple archiving issues (kde#456346)
  * Fix possible sequence corruption (kde#480398)
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Fix transparency lost on rendering nested sequences (kde#477771)
  * Fix guides categories not applied on new document (kde#477617)
  * Check MLT's render profiles for missing codecs.
  * Fix crash on auto subtitle with subtitle track selected
  * Fix qml warning (incorrect number of args)
  * Fix audio stem export
  * When pasting clips to another project, disable proxies Fixes #1785
  * Don't allow creating profile with non standard and non integer fps from a clip Related to #476754
  * Fix mix not always deleted when moving grouped clips on same track
  * Fix remap crashes
  * Ensure timeremap option is disabled when effect is deleted
  * Time remap: fix changing speed broken / crashing
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * Fix remap crashes
  * Ensure timeremap option is disabled when effect is deleted
  * Time remap: fix changing speed broken / crashing
  * Fix timeremap
  * Fix replace clip keeping audio index from previous clip, sometimes breaking audio.
  * Create sequence from selection: ensure we have enough audio tracks for AV groups
  * Fix timeline duration incorrect after create sequence from timeline selection
  * Fix project duration not updating when moving the last clip of a track to another non last position
  * Don't lose subtitle styling when switching to another sequence (kde#476544)
  * Fix crash dropping url to Library
  * When dropping multiple files in project bin, improve import speed by not checking if every file is on a remote drive
  * Fix titler shadow incorrectly pasted on selection. (kde#476393)
  * Fix pasted effects not adjusted to track length
  * Fix timeline preview ignored in temporary data dialog. (kde#475980)
  * Speech to text: fix whisper install aborting after 30secs. Text based edit: allow creating a new timeline sequence with current edit
  * Don't try to generate proxy clips for audio with clipart
  * Clip loading: switch to Mlt::Producer probe() instead of fetching frame. (kde##475554)
  * Multiple fixes for time remap losing keyframes
  * Add png with alpha render profile
  * Fix Mix not correctly deleted on group track move
  * Fix rendering with alpha
  * Rotoscoping: don't auto add a second kfr at cursor pos when creating the initial shape, don't auto add keyframes until there are 2 keyframes created
  * Fix keyframe param not correctly enabled when selecting a clip
  * Fix smooth keyframe path sometimes incorrectly drawn on monitor
  * Properly adjust timeline clips on sequence resize
  * Remove unused debug stuff
  * Fix project duration not correctly updated on hide / show track
  * Fix resize clip with mix test
  * Fix resize clip start to frame 0 of timeline not correctly working in some zoom levels, Fix hanging test
  * snapcraft: initial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- Changes since 23.08.1:
  * Fix Fit Zoom (kde#472754)
  * Fix cannot move clip to 0 in some cases. Fixes #1759
  * Fix erratic behavior when requesting to add same track transitions (mixes) to several clips. Fixes #1761
  * Redirect Settings > Configure Kdenlive > Help to the online documentation
  * Fix multiple audio streams broken by MLT's new astream property (kde#474895)
  * Fix dialogs not correctly deleted, e.g. add track dialog, causing crash on exit
  * Ensure clips with audio (for exemple playlists) don't block audio when inserted on video track
  * ensure translations cannot mess with file extensions
  * Fix another case blocking separate track move
  * Fix grabbed clips cannot be moved on upper track in some cases
  * Fix move clip part of a group on another track not always working
  * Fix playlist count not correctly updated, allowing to delete last sequence (kde#474988)
  * Fix motion-tracker Nano file name and links to the documentation
  * Stop installing kdenliveui.rc also as separate file, next to Qt resource
  * Fix tests and possible corruption in recent mix fix
  * Correctly highlight newly dropped files in library
  * Fix threading issue crashing in resource widget. Fixes #1612
  * Fix freeze on adding mix Related to #1751
  * Make Lift work as expected by most users (kde#447948,kde#436762)
  * Fix load task discarding kdenlive settings (caused timeline clips to miss the "proxy" icon
  * Fix multiple issues with Lift/Gamma/Gain undo (kde#472865, kde#462406)
  * Fix freeze / crash on project opening
  * Optimize RAM usage by not storing producers on which we did a get_frame operation. Slows down thumbnail creation but saves some RAM.
  * Fix guide multi-export adding an extra dot to the filename
  * COrrectly update effect stack when switching timeline tab
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Fix audio channel setting breaking opening of existing project file
  * Fix possible crash in audiolevel widget
  * Fix default audio channels for project not correctly saved
  * Fix guide/marker categories all black on some non english locales
  * Ensure Media browser saves zoom level when using mouse wheel to zoom Fixes #1754
  * Extract audio: export only active streams, merge all if requested
  * Fix crash on subclip transcoding Fixes #1753
  * Fix audio extract for multi stream clips
  * When restoring audio or video component in timeline, first try target track, then mirror track Fixes #1749
  * Fix multi guide export enabled by default Fixes #1750
  * Fix guides categories all black when opening a project from a different locale
  * Fix archiving crash on Windows caused by filesystem case sensitivity
  * Project Bin: don't draw icon frame if icon size is null
  * Fix zone rendering not remembered when reopening a project
  * Fix detection/fixing when several clips in the project use the same file
  * Correctly update guides list when switching timeline tab
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Allow speed effect on sequence/playlist items that already had it so it can be disabled in existing projects
  * Disable speed change on playlist and sequence clips, as it is unstable in MLT.
  * When an MLT playlist proxy is missing, it should be reverted to a producer, not stay in a chain
  * Fix proxy clips not correctly recreated when missing on project open
  * Fix no luma files for NTSC and other non HD formats
  * Fix crash closing luma download dialog
  * Ensure saved effect position is relative for fades (kde#473375)
  * Fix Save As incorrectly triggering backup file.
  * Fix layout file warning
  * Fix path of LUT files on project opening, for appimage or imported projects
  * Fix composition incorrectly selected after added through clip corner shortcut
  * Fix crash closing project with mixes
  * Fix timeline keyframe view broken afer remove keyframes or undo effect deletion
  * Fix 'Save As' behaving like 'Save a Copy'
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Don't incorrectly update timeline duration on every clip move. Related to #1738
  * Improve highly inefficient loop Related to #1422
  * Fix warnings
  * fix melt path config variable not renamed everywhere
  * Fix timeline zone not correctly loaded on project open
  * Fix timeline preview incorrectly connected when opening pre-nesting project file
  * Fix crash tring to import DJI image stream (kde#467375)
  * Fix crash dragging multistream clip outside timeline
  * Fix play icon incorrectly active when playing from end, fix timeline not playing from start (kde#473087)
  * Fix crash on audio record with multiple timeline sequences Related to #1731
  * Ensure lines and dust effects have in/out defined
  * Fix pasting keyframeble effect from one clip to another breaks if destination clip is shorter
  * Fix timeline preview (and possible rendering) crash on title clips.
  * Fix timeline preview not loaded on project opening
  * Fix missing effects/compositions when rendering a project with several sequences
  * Ensure Kdenlive's renderer path is always found or fixed
  * Disable mediabrowser constantly checking for directory changes when widget is not visible
  * Fix Render Widget url dialog not working properly (cannot choose another folder)
  * Fix timeline focus when a drop quickly exits an existing timeline clip and that the  exit event is not triggered Related to #1704
  * Fix freeze effect to select current playhead frame by default
  * MLT does not support animated colors for avfilter. (kde#472722)
  * Fix crash on project close introduced in last commit
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Fix crash loading project with an unknown transition
  * Fix crash trying to open backup for moved project file.
  * Switch vglobal_quality to vqp for nvenc (same as Shotcut)
  * backport ASAN fix from master
  * Fix ASAN use after freed
  * Mixer: polish audio levels display, add scale for gain slider
  * Fix audio levels gradient colors
  * Mixes: ensure asset panel cleared on undo insert, fix mix
    inserted at wrong clip end on drop
  * Fix mixes incorrectly saved as luma
  * Ensure Subtitle widget can fit on smaller screens.
  * Fix crash pressing Home on subtitle track
  * Fix effects disappearing from timeline sequence and other
    sync issues
  * Fix tests
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Fix freeze on duplicate sequence
  * Get rid of mocking in some more tests
  * Re-enable timeline sequence thumbnails
  * Fix tests
  * Nesting: refactor timeline sequence open/close, add tests
  * Display default folder for VOSK models in settings page when no custom folder is set.
  * Fix closing sequence in reopened project losing all recent changes
  * Fix crash pasting subtitle in a timeline sequence without subtitles
  * Fix dragging clip in timeline can cause out of view scrolling
  * Fix motion tracker not working on rotated clips or clip with distort effects
  * Fix import clip on single click in Media Browser
  * Fix focus issue after switching from fullscreen monitor
  * Cleaner version of previous patch
  * Fix multiple guides export. BUG: 469435 (kde#469435)
  * Fix color wheel resetting color on mouse wheel.
  * Minor UI adjustments to timeline ruler
  * Use better option for Media Browser. Related to #1471
  * Drop timeline zoom whatsthis (it interferes with zoom shortcut (Shift+Ctrl++)
  * Merge !399 with a few fixes (whisper disable FP16 on GTX 16xx)
  * Don't allow archiving unsaved project, show subtitle files in archive widget and project files list
  * Fix scaled rendering
  * Titler: shadow should include text outline. Fixes #1689 (requires latest MLT git)
  * Thumbnailer: ensure producer is valid, don't seek past clip end
  * Fix create sequence from selection resulting in incorrect clip length
  * Don't trigger producer reinsert multiple times on change
- Require knewstuff-imports at runtime
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Too many changes since 23.04.0, only listing bugfixes:
  * Fix Defish range for recently introduced parameters (kde#469390)
  * Fix animated color parameter alpha broken (kde#469155)
  * Don't attempt to move external proxy clips (kde#468998)
  * Fix crash on unconfigured speech engine (kde#469201)
  * Fix VOSK model hidden from auto subtitle dialog. (kde#469230)
- Drop patch, merged upstream:
  * 0001-Fix-project-corruption-on-opening-add-test-to-preven.patch
* Mon May  1 2023 Christophe Marin <christophe@krop.fr>
- Add upstream fix for kde#468962:
  * 0001-Fix-project-corruption-on-opening-add-test-to-preven.patch
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
- Drop patch, merged upstream:
  * 0001-Fix-designer-plugin-crash.patch
* Thu Dec 29 2022 Christophe Marin <christophe@krop.fr>
- Add patch to prevent a designer-qt5 crash (boo#1206680):
  * 0001-Fix-designer-plugin-crash.patch
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 28 2022 Christophe Giboudeaux <christophe@krop.fr>
- Recommend installation of the mediainfo executable (boo#1202848)
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * [Render Widget] Refactoring and feature extension (kde#415610)
  * "Add Marker/Guide quickly" allow shortcut * only on keypad
    (otherwise * is ambigous with Shift++) (kde#434411)
  * Fix action name: "Save Timeline Zone to Bin" is not what it does (kde#436386)
  * Try to improve alpha render quality (kde#436879)
  * Fix alpha render and add utvideo (kde#448010)
  * [OTIO] Differentiate between read and write adapters (kde#448318)
  * Add python interface (kde#423083)
  * Don't attempt to create audio thumbs if thumbs are disabled. (kde#448304)
  * Use a SPDX standard license identifier in Appstream data (kde#448134)
  * Make it possible to enable/disable track with a shortcut (kde#440181)
- Drop obsolete patch:
  * 0001-Handle-the-melt-package-rename-nicely.patch
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Too many changes to list here.
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Fix sometimes cannot move grouped clip right when only 1 empty frame
  * when saving effect, show it under its name, not id in effect list
  * Fix fade effects not correctly saved or pasted.
  * Fix clip monitor allowing seek past clip length with transparency background enabled
  * Fix green tint on first image extract.
  * minor cleanup of add marker ui
  * Ensure thumbnail preview profile is not changed by clip resolution
  * Fix alpha render and add utvideo (kde#448010)
  * Fix freeze trying to drag a clip that was just added to Bin.
  * Uptade frei0r.scale0tilt.xml with Scale X and Y parameters now animated
  * Fix cherry-pick typo
  * Fix timeline ruler not working after effect drop in some circumstances.
  * Fix various bugs in timeremap (keyframes random move, crashes)
  * Time Remap: don't allow keyframe after last frame of source clip
  * Protect timeline preview list with mutex
  * Fix slideshow duration not updated on profile change
  * Fix detection of missing timeline preview chunks on opening
  * Don't attempt to create audio thumbs if thumbs are disabled. (kde#448304)
  * Speedup loading of projects with timeline preview.
  * Add some default LUT files
  * [Wizzard] Update link to troubleshooting docs
  * Try to find mediainfo on windows automatically too
  * [Setup Wizard] Show codes if there are only info messages, fix doc link
  * Disable "Change Speed" and "Time Remap" actions if the other one is active (kde#443613)
  * Check for mediainfo in setup wizard
  * Fix extract frame on Windows (also used for Titler and scopes)
  * Improve monitor zoom (kde#434404)
  * Use a SPDX standard license identifier in Appstream data (kde#448134)
  * Rename forgotten rgb24 and rgb24a after MLT 7 port
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Fix multiple bins should always stay tabbed together.
  * Fix shortcuts sometimes broken on fullscreen monitor.
  * Enforce 29.97 fps when using a clip with 29.94 or 29.96 fps.
  * Fix audio thumbs not created after profile change.
  * Fix compilation warnings (function type compatibility)
  * Ripple: fix strange behaviour on Windows and macOS
  * Add xml ui for audiolevelgraph effect and other xml format fixes
  * Improvements and fixes for the status bar message field
  * Add ripple test for single track groups
  * Fix ripple in several scenarios with groups
  * Improve Keybind Info with compositions
  * Fix crash on clip insert in ripple mode
  * Fix archiving.
  * Fix keyframe disappearing in timeline after moving the previous one in effect stack
  * Don't allow undo when resizing clip/composition (fixes crash)
  * Fix freeze on multiple title clip duplication. (kde#443507)
  * Fix mistake in last commit
  * Various fixes on project opening with missing proxies (playlist and timeremap broken)
  * Add more ripple tests
  * Fix ripple of groups after commit c1b0f275
  * Restructure ripple code to make it possible to run more tests
  * Fix mix corruption when moving a clip with start and end mixes to another track, add test
  * Fix concurrency crash with autosave and multicam mode
  * Fix crash on extract frame if image was already part of the project
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Don't allow typewriter effect on clip other than text (caused a freeze)
  * After extract operation, seek cursor to in point
  * Fix possible crash on rotoscoping edit
  * Fix crash on misconfigured wipe composition. (kde#446203)
  * keyframe import fixes: crash importing to effect rect without opacity,
    fix motion tracker exporting with opacity=0, fix limiting keyframes
    messing import
  * Fix crash importing empty keyframes
  * Update 21.12 splashscreen
  * Fix keyframe selection on add
  * Fix add keyframe does not selected
  * Fix extract frame using monitor preview resolution
  * Fix pasting items in timeline to use mouse / cursor position depending
    on how it is called menu / shortcut
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Too many changes since 21.11.80, only listing bugfixes:
  * Fix crash using spacer tool on grouped clips with a clip in
    the group positioned before spacer start operation. (kde#443324)
  * Track name edit: fix focus issue, enable F2 shortcut (kde#440185)
  * "Go to clip start/end" should use clip under cursor if none is selected (kde#440024)
  * Typewriter effect should not be blacklisted! (kde#445232)
  * Fix "Select Transition" should select mixes too (kde#440023)
  * Fix default project path ignored on creating new project (kde#444595)
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * Make it possible to copy and import rotoscoping keyframes (kde#442372)
  * Remove broken "duplicate bin clip with timeremap" stuff that caused crash
    dropping playlists in timeline (kde#441777)
  * Crop effect: use project resolution by default(solves proxy issue). (kde#408235)
  * Add a tooltip to the track effects toggle button in the track header (kde#440218)
  * Fix build with -DCRASH_AUTO_TEST=ON (kde#440414)
- Drop obsolete patch:
  * 0001-Handle-the-melt-package-rename-nicely.patch
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- Too many changes to list here.
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Too many changes since 21.08.1, only listing bugfixes:
  * Remove broken "duplicate bin clip with timeremap" stuff that caused crash
    dropping playlists in timeline (kde#441777)
  * Crop effect: use project resolution by default(solves proxy issue). (kde#408235)
  * Fix crash on pasting grouped subtitle (kde#439524)
  * Fix noise when setting producer (e.g. when opening a project) (kde#433847)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Compile MLT with GCC 9 - fixes brightness effect corruption
  * Fix mix crossfade sometimes using wrong order (starting at 100%% and ending at 0%%) instead of reverse
  * Upgrade document version and fix custom affine effects for MLT 7 when opening older project file
  * Make it possible to import mlt rect keyframes to frei0r.alphaspot
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- Too many changes since 21.07.90, only listing bugfixes:
  * Don't allow deleting items when a spacer move operation is running. (kde#408434)
  * Fix crash moving clip with speed effect and mix. (kde#433579)
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Too many changes since 21.07.80, only listing bugfixes:
  * Drop custom combobox stylesheet causing unreadable text. (kde#428755)
  * Fix crash dragging multiple audio streams clip in timeline with locked
    tracks (kde#439849)
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * Dynamically update max number of concurrent proxy/transcode jobs,
    don't show error message on job abort (kde#432365)
  * Correctly display info on error with jobs, fix stablize add clip checkbox not working (kde#436805)
  * Keyframes widget: add option to copy values at cursor pos to clipboard (kde#439284)
  * Import keyframes dialog: make position alignment more customizable (kde#426316)
  * Remove DVD Wizard (kde#403128)
  * Implement check and transcoding for non seekable files. (kde#371062)
  * Add option to go to start if playback started on timeline end (kde#353051)
- Drop 0001-Handle-the-melt-package-rename-nicely.patch
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- Changes since 21.04.2:
  * Fix crash closing project with a mix on a clip with keyframable effect.
  * Fix speech to text after recent VOSK api change (kde#438306)
  * Cleanup font setting for qml timeline
  * Add webp mime type to clip creation dialog
  * Fix startup crash on Wayland, thanks to login.kde@unrelenting.technology (kde#431505)
  * Mix: Fix first clip out not correctly reset on second clip deletion
  * Fix crash on exit when a mix is selected
  * Resolved Bug 436895 - "Rotoscoping not working right"
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Too many changes since 21.04.1, only listing bugfixes:
  * Fix effect sliders on right to left (rtl) layouts (kde#434981)
  * Fix alignment of statusbar message label (kde#437113)
- Add patch to update kdenliverc automatically with the new melt
  name: 0001-Handle-the-melt-package-rename-nicely.patch
* Tue May 25 2021 Wolfgang Bauer <wbauer@tmo.at>
- Remove unneeded libmlt-devel BuildRequires
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Too many changes since 21.04.0, only listing bugfixes:
  * Invalidate preview render on subtitle actions (kde#435692)
  * Improve naming of newely created profile (kde#385981)
  * Fix several archiving issues with mlt files (kde#435882)
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- Too many changes since 21.03.90, only listing bugfixes:
  * Fix in point calculation on speed revert. (kde#424582)
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Too many changes to list here.
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Too many changes since 20.12.2, only listing bugfixes:
  * Fix recursive search broken on cancel. (kde#433773)
  * Titler: update tab order (kde#433590)
  * Transcode job: don't silently overwrite exported files. (kde#433623)
  * Do not allow zero for values of a project profile (framrate, framesize,…) (kde#432016)
  * Fix invisible text cursor in title editor #165 and other minor tweaks (kde#403941)
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Too many changes since 20.12.1, only listing bugfixes:
  * Fix lift value incorrect on click (kde#431676)
  * implement missing subtitle copy/paste. (kde#430843)
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Too many changes since 20.12.0, only listing bugfixes:
  * Fix crash when all audio streams of a clip were disabled. (kde#429997)
  * Add "unused clip" filter in Project Bin.(kde#430035)
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Too many changes since 20.11.90, only listing bugfixes:
  * Fix image sequences broken on project opening. (kde#429798)
  * Fix left part of a cut cannot be selected right after processing (kde#428544)
  * Fix remove space not working until context menu called. (kde#429868)
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Too many changes to list here.
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Fix crash on some projects opening (kde#409477)
  * Fix crash removing a fade effect added twice. (kde#425175)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Too many changes to list here.
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Too many changes since 20.08.1, only listing bugfixes:
  * Fix crash on some projects opening (kde#409477)
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Too many changes to list here.
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- Changes since 20.07.90:
  * Fix clip monitor zoom not reset when changing clip, and zone incorrect on zoom
  * Missing fix for FreeBSD in last commit (fix broken localization)
  * Attempt to fix UI translations broken. (kde#424967)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Too many changes to list here.
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * Ensure auto-saved file is newer than project before proposing to recover data. (kde#424016)
  * Archive project: fix clip with speed effect url not updated, resulting in missing clip message. (kde#422135)
  * integrate clip rating with undo/redo. (kde#421552)
  * Locate clip: select file in file manager (kde#421365)
  * Fix glitch in bin item selection, causing some actions to be disabled (kde#420628)
  * Fix freeze when changing bin selection (kde#419604)
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Fix drop in timeline from clip monitor possible crash and disappearing clip (if mouse released above track headers)
  * Fix working on project with proxy only
  * Ensure we have a valid context before drawing keyframes
  * Don't attempt activating a monitor if it is hidden.
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Too many changes since 20.04.1, only listing bugfixes:
  * Archive project: fix clip with speed effect url not updated, resulting in missing clip message. (kde#422135)
  * Fix set audio reference incorrectly disabled on AV grouped clips (kde#421669)
  * Locate clip: select file in file manager (kde#421365)
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Too many changes since 20.04.0, only listing bugfixes:
  * Fix template title clips in timeline resetting duration on project re-open (kde#420823)
  * Fix aspect ratio not working on title images (kde#420676)
  * Fix glitch in bin item selection, causing some actions to be disabled (kde#420628)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Too many changes since 20.03.90, only listing bugfixes:
  * Fix freeze when changing bin selection (kde#419604)
  * Export frame should use source resolution instead of project resolution (kde#419824)
  * Fix crash opening old project file (kde#419563)
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Too many changes since 20.03.80, only listing bugfixes:
  * Ensure we cannot create a project with 0 tracks (kde#419019)
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Fix duplicate multiple clips only duplicating first item (kde#418379)
  * Fix changing of title clip duration broken (kde#417505)
  * Fix tile clips created with monitor preview res (kde#417368)
  * Fix forward/rewind affecting wrong monitor (kde#416917)
  * Enable clip jobs and convert/extract audio on subclips (kde#416616)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Too many changes since 19.12.2, only listing bugfixes:
  * Fix changing of title clip duration broken (kde#417505)
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Too many changes since 19.12.1, only listing bugfixes:
  * Fix effect with long names prevent easy access to effect actions. (kde#416420)
- Dropped patches, now upstream:
  * 0001-Fix-crash-on-new-project-with-Qt-5.14.patch
* Sun Jan 26 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Fix-crash-on-new-project-with-Qt-5.14.patch to fix a crash
  when loading projects (kde#416766, boo#1161548)
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Too many changes to list here.
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Too many changes since 19.11.90, only listing bugfixes:
  * Fix video thumbnails from previous project showing up. (kde#414813)
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Too many changes since 19.11.80, only listing bugfixes:
  * Fix disabled effect stack state. (kde#408242)
  * Apply track effects on main playlist and not on tractor. (kde#414367)
  * Fix zoom slider not updating after zoom-fit (kde#413469)
  * We actually need Qt5.11, and so KF5.45 should be here too (kde#414165)
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * Fix keyboard handling in monitor fullscreen mode,
    thanks to Martin K. (kde#413644)
  * Fix compositions disappear after reopening project with locked
    track (kde#412369)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Too many changes since 19.08.2, only listing bugfixes:
  * Try to make it compile with gcc 9 (kde#413416)
  * Fix compositions disappear after reopening project with locked track. (kde#412369)
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Too many changes to list here.
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Fix disabling clip only disable audio part of an AV clip. (kde#411466)
  * Fix regression breaking timeline resize
  * Fix timelinekeyboard focus on start and grab not correctly ended
  * default effects to video
  * Fix disabling autoscroll.
  * Convert old custom effects to new customAudio/Video naming
  * Fix group move sometimes moving clip very far from expected location.
  * Ctrl resize in monitor effects keeps center position
  * Shift resize in monitor effect keeps aspect ratio
  * Update appdata version
  * Fix effect/composition list filter working on untranslated strings
  * Merge branch 'rgb_parade' into 'master'
  * Fix custom effects not recognized as audio
  * Fix encoder speed ignored (kde#411000)
  * Late update of version in appdata..
  * Use the parameter readable and translatable name instead of its formal name for the color edit widget
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Do not setToolTip() for the same tooltip twice
  * Use translations for asset names in the Undo History
  * Fix dropping clip in insert/overwrite mode
  * Fix timeline drag in overwrite/edit mode
  * Fix freeze when deleting a group with clips on locked tracks.
  * Fix crash when dragging clip in insert mode. (kde#409577)
  * Use the translated transition names in the 'Properties' header
  * Fix freeze and fade ins allowed to go past last frame
  * Fix revert speed clip reloading incorrectly
  * Fix copy/paste of clip with negative speed
  * Fix issues on clip reload: slideshow clips broken and title duration reset
  * Fix slideshow effects disappearing.
  * Fix track effect keyframes
  * Fix track effects don't invalidate timeline preview
  * Fix effect presets broken on comma locales, clear preset after resetting effect
  * Fix crash in extract zone when no track is active.
  * Fix reverting clip speed modifies in/out
  * Fix audio overlay showing up randomly.
  * Fix Find clip in bin not always scrolling to correct position.
  * Fix possible crash changing profile when cache job was running
  * Fix editing bin clip does not invalidate timeline preview.
  * Fix audiobalance (MLT doesn't handle start param as stated)
  * Fix target track inconsistencies: 3 state button, hide when shouldn't be available
  * Make the strings in the settings dialog translatable
  * Make effect names translatable in menus and in settings panel
  * Remember last target track and restore when another clip is selected
  * Dont' process insert when no track active, don't move cursor if no clip inserted
  * Correctly place timeline toolbar after editing toolbars
  * Lift/gamma/gain: make it possible to have finer adjustments with Shift modifier
  * Fix MLT effects with float param and no xml description
  * Cleanup timeline selection: rubber select works again when starting over a clip.
  * Attempt to fix Windows build
  * Various fixes for icon view: Fix long name breaking layout, fix seeking and subclip zone marker
  * Fix some bugs in handling of NVidia HWaccel for proxies and timeline preview
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Add 19.08 screenshot to appdata
  * Fix bug preventing sequential names when making serveral script renderings from same project
  * Fix compilation with cmake < 3.5
  * Fix extract frame retrieving wrong frame when clip fps != project fps (kde#409927)
  * Don't attempt rendering an empty project
  * Fix incorrect source frame size for transform effects.
  * improve subclips visual info (display zone over thumbnail), minor cleanup
  * Small cleanup of bin preview thumbnails job, automatically fetch 10 thumbs at insert to allow quick preview and fetch another 40 when seeking is requested
  * Fix project clips have incorrect length after changing project fps
  * Fix inconsistent behavior of advanced timeline operations.
  * Fix "Find in timeline" option in bin context menu
  * Support the new logging category directory with KF 5.59+
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Fri Jul 19 2019 wbauer@tmo.at
- Use kf5_debugdir macro for specifying the logging categories location
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Too many changes to list here
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Too many changes to list here
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Too many changes to list here
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Too many changes to list here
- Dropped patches, now upstream:
  * fix-rttr-target-name.patch
  * fix-rttr-target-typo.patch
* Fri Apr 12 2019 Wolfgang Bauer <wbauer@tmo.at>
- Require libqt5-qtquickcontrols2, needed on runtime by the new
  timeline
* Wed Apr 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Add upstream patches to fix building with rttr:
  * fix-rttr-target-name.patch
  * fix-rttr-target-typo.patch
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Too many changes to list here
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Update copyright year also.
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix empty warning dialog on missing font in project (kde#401903)
  * Fix bin item description cannot be edited if it contains zone subclips (kde#402817)
  * Fix screengrab with audio broken
  * Move Gain effect to "Audio correction" category
  * ci: enable freebsd build
  * QtScript is not used anymore
  * ci: add recipe for gitlab CI
  * Fix incorrect color theme correction for AppImages
  * Fix color theme lost on AppImage
  * Update AppData app version
  * Fix bin/melt.exe & libmlt* loading on Windows
  * necessary OpenGL headers are provided by Qt
  * Fix keyframes import
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Fix crash on image sequence import
  * Backport fix for titler text gradient
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Add donation url to appdata
  * Fix minor EBN issues and typos
  * Fix play/pause on Windows
  * Sync quickstart manual with UserBase
  * Install doc files
  * Make it compiles when we use QT_NO_NARROWING_CONVERSIONS_IN_CONNECT
  * Fix minor EBN issues
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Fix finding MLT data in build-time specified path
  * Fix play/pause on Windows
  * Try catching application initialization crashes
  * Fix MinGW build script misses
  * Backport some Shotcut GLwidget updates
  * Fix MinGW build
  * Install doc files
  * build scripts for Linux & Windows
  * Backport packaging scripts
  * Fix MinGW build
  * Backport fix for incorrect bin rename
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Improve missing luma detection (region transition) - fixes project crash
  * Home/End now also seek in clip monitor
  * Update AppData for upcoming release
  * Windows crash reports
  * Update authors
  * Fix double clicking a title clip in bin tries to rename instead of opening the title dialog
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix proxy creation not restarting when changing a property while creating proxy
  * Prepare AppData for next release
  * Fix clip proxy on autorotate (kde#397762)
  * Fix effects parameters parsing
  * Give priority to local effects over system ones
  * Access to MLT debug info (command line option)
  * Fix OffScreenSurface creation in GUI thread
  * Increase max unzoom level, uniform zoom factor
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix custom lift/gamma/gain displaying wrong UI (kde#364127)
  * Updated appdata
  * Fix possible crash in monitor restart
  * Reduce minimum profile widget height to make dialog fit in screen (kde#384511)
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Require MLT 6.10 (to avoid the incompatible 6.8)
  * Fix compile warning
  * Backport KF5 Purpose share feature
  * Backport fix for incorrect gap in texts
  * Update readme with correct infos
  * Scale TitleTemplateDialog preview with the window
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Don't display Wizard on every AppImage startup
  * Fix message extraction
  * Prepare for 18.04.2 release
  * Rename mime type file to make flatpak happy
  * Fix crash with MLT 6.8.0 and some keyfameable parameters (box blur)
  * Consistent behavior for mouse wheel: down goes forward, up goes backwards (kde#394341)
  * Update readme with correct infos
- Dropped patches, now upstream:
  * fix-crash-with-mlt-6.8.0.patch
* Wed May 23 2018 wbauer@tmo.at
- Add fix-crash-with-mlt-6.8.0.patch to fix crashes with mlt>6.6.0
  when using effects with some keyframeable parameters (kde#394275)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * update monitor safezone overlay
  * Update appdata version
  * Improve titler default background color
  * Fix build with Qt 5.11_beta3 (dropping qt5_use_modules)
  * Only check color theme on first run, not each time the Wizard is called (kde#388274)
* Thu Apr 19 2018 wbauer@tmo.at
- Raise minimum mlt version to 6.6.0
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Fix luma files lost when opening project with AppImage
  * Stop looking for DVD related apps on startup
  * Update AppData version for comming release
  * Scale TitleTemplateDialog preview with the window
  * Fix rendering using custom folder when not requested (kde#387135)
  * Fix double separator in project/capture folder
  * Fix possibly wrong message on moving project folder
  * Fix regression breaking fades and other effects on resize
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Fix lowres icons on highdpi (kde#390104)
  * Fix crash when initializing offscreen surface in GLWidget
  * Move knsrc files in Qt resource so we find them without install (kde#392201)
  * Fix build with Qt 5.11 (missing headers)
  * Fix project settings vertical scrollbar on open
  * Update minimum MLT version to latest release (fixes audio mix problem)
  * Fix AppImage screenshot (kde#388676)
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Use KAboutData::setDesktopFileName instead of QGuiApplication version.
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Fix compatibility with MLT >= 6.6.0
  * Fix build with Qt 5.6
  * Fix backwards seeking not stoping when reaching clip start
  * Add release version number to AppData
  * Don't query available widget styles on each startup
  * Fix webM encoding (auto replace vorbis by libvorbis if installed) (kde#388503)
- Dropped patches, now upstream:
  * fix-build-with-Qt5.6.patch
* Wed Jan 17 2018 wbauer@tmo.at
- Escape the usage of %%{NAME} when calling out to rpm.
  RPM 4.14 has %%{NAME} defined as 'the main package's name'.
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix translation install
* Wed Jan  3 2018 wbauer@tmo.at
- Add fix-build-with-Qt5.6.patch to make it compile on standard
  Leap 42.3
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * remove useless audio bitrate on pcm proxy encoding
  * Update proxy profiles
  * Make sure playlist proxies have an even height
  * Fix crash on playlists concurrent jobs using library clips
  * Timeline preview fixes: Don't invalidate on expand/collapse effect, invalidate on master clip edit
  * Don't restart clip if trying to play backwards from clip monitor end
  * Use smaller size for image proxies (kde#353577)
  * Fix playing backwards forwards one second (kde#375634)
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Fix extension in transcode file dialog
  * Sort clip zones by position instead of name
  * Set a proper desktop file name to fix an icon under Wayland.
  * FreeBSD does not have sys/asm.h -- for what is this include needed on linux?
  * doc: fix option (qwindowtitle instead of caption)
  * Fix terminology: mimetype(s) -> MIME type(s)
  * Fix UI string: Control Center -> System Settings
  * Const'ify code
  * fix import image sequence
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Set a proper desktop file name to fix an icon under Wayland.
  * Sort clip zones by position instead of name
  * Fix melt.exe finding on windows
  * Revert "Windows: terminate KDE session on window close"
  * Make KCrash optional
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix autosave : workaround KAutoSaveFile bug with non ascii chars
  * Get ready for transform centered rotation
  * Fix keyframes unseekable on bin effects
  * Fix lift to handle negative values (requires latest MLT version)
  * Prefer SDL2 to SDL1 (dropped by FFmpeg and so MLT)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Remember last selected title template
  * Fix proxy error (height not multiple of 2) (kde#384345)
  * Fix extract frame from bin exporting lower than source image
  * Fix visibility check of tracks in multitrack-view
  * Allow disabling autosave until we improve it (kde#384197)
  * Windows: find Kdenlive lumas (kde#375337)
  * Windows: terminate KDE session on window close (kde#380854)
  * Windows: always use bundled MLT (kde#380036)
  * Remove project profiles sharing (knsrc) (kde#383238)
  * Gardening: fix GCC warnings (8)
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Fix crash on importing multistream clip (kde#381584)
  * Fix crash when creating proxies - real issue not yet fixed
  * fix compile (gcc7) (kde#379688)
  * show info on MLT found by CMake
  * non-portable flag, let build system handle it
  * Windows icons are delivered in icontheme.rcc
  * Fix compilation
  * Fix custom profile not found on creation
  * Fix loop zone (kde#378813, kde#381146)
- Remove patches, now upstream:
  * gcc7-fixes.patch
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Forgot this file in previous commit :(
  * Fix crash changing title font for 2nd time (kde#379606)
  * more Windows rendering fixes
  * Fix init of geometryWidget
* Mon May 29 2017 wbauer@tmo.at
- Add gcc7-fixes.patch to fix build with gcc7 (boo#1041232)
* Tue May 23 2017 wbauer@tmo.at
- Only use the %%kf5_find_htmldocs macro on Leap 42.3 and higher,
  this should fix the build for 42.2 on Packman
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Fix title clip duration cannot be changed (kde#379582)
  * Allow passing pre-parameters using "-i" to specify where the input file name should go in ffmpeg parameters
  * Fixed off-by-one errors in fft-based cross-correlation computations
  * Don't show color theme configuration option unavailable on Windows (kde#375723)
  * Fix temp path on Windows (kde#375717)
  * Fix MLT doc link (kde#375316)
  * Fix script export & QScript header left
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Don't show color theme configuration option unavailable on Windows
  * Fix temp path on Windows
  * Fix MLT doc link
  * Fix script export & QScript header left
  * Fix glitch on pause and does not play last second of project (kde#371762)
  * remove QScript dependency
  * Fix render scripts on Windows: generate .bat files
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Fix possible crash on rendering with "play after render" option
  * Images also use qimage producer
  * fix Windows build with C++ threads
  * Fix some effects incorrectly initialized on tracks (kde#378071)
  * Remove beta message in preparation of release
  * Fix locked ratio scaling
  * Fix archived project wrong path and missing images/slideshows
  * More clever ratio locking in effect/transition
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar 23 2017 wbauer@tmo.at
- Don't generate the oxygen icon theme cache on (un)installation,
  no oxygen icons are getting installed
- Drop use-mlt_datadir.patch, no longer necessary since a while
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix crash & corruption on dragging multiple clips in timeline, fix thread warning on monitor refresh
  * Avoid possible profile corruption with xml producer
  * Avoid relying on xml to clone a clip.
  * src/dvdwizard/dvdwizardmenu.cpp: do not show "grid" in output (kde#377256)
  * src/dvdwizard/dvdwizard.cpp: fix file loading in slotLoad (kde#377254)
  * Fix Render Widget's file dialog not working correctly (requires KDE Frameworks >= 5.33) (kde#371685)
  * Fix render job duration when past midnight (kde#372370)
  * Fix Bin Effect reset (kde#376494)
  * Fix unnecessary refresh of tools when selecting titler item
  * Fix fadeouts re-appearing on clip cut+resize
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Mon Jan 30 2017 guoyunhebrave@gmail.com
- Add frei0r-plugins recommends
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
- Drop the full url for the source file. This is causing issues
  when submitting non-released versions and causes false declines
  from factory-auto
* Thu Dec  8 2016 lbeltrame@kde.org
- Fix source URL
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 19 2016 wbauer@tmo.at
- Require libqt5-qtquickcontrols, it doesn't start without it (boo#994649)
- Minimum required mlt version is 6.0.0 now
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Sat Jul  2 2016 fvogt@suse.com
- Update required MLT version to 0.9.8 to avoid failing builds
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sun Feb  7 2016 wbauer@tmo.at
- Add BuildRequires: pkgconfig(libv4l2) to fix boo#959174
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
- Drop upstreamed patches:
  * kdenlive-0.9.10-no_avformat.patch
- Renamed and adjusted patch
  * use-mlt_datadir.patch
* Thu Oct 16 2014 nico.kruber@gmail.com
- Update to 0.9.10
  + handle VBR encoding profiles, and use it!
  + video stabilizer: added new "vid.stab", removed older ones
  + environment variable MLT_PREFIX overrides profiles & melt path
  + several fixes for high dpi screens
  + change proxy profile, obsolete with libav
  + add SVG to image formats for slideshows
  + restore project render bitrate (#3326)
  + show proxy name in clipproperties
  + add link to MLT doc in render edit dialog (#3355)
  + update maximum track height (#3241)
  + resize render path box (#3300)
  + change transition settings layout (#3336)
  + heat colormap in spectrogram (#3142)
  + fix clip monitor switch on proxy creation end (#3308)
  + fix clip jobs (stabilize) operating on proxies (#3337)
  + fix timeline corruption by clip resize end + zoom change
  + fix title clip duration not taken into account (#3309)
  + fix timeline thumbs flicker when fully zoomed (#3247)
  + fix thumbnailer aspect ratio
  + fix fades for split audio (#3323)
  + fix transcoding (#3334)
  + fix 'Clip in Timeline' when project monitor is inactive (#3261)
  + fix audio analysis (use dynamic memory instead of stack)
  + fix render end notification
  + fix render timecode overlay (#3260)
  + set tooltip for monitor pause button (#3256)
  + fix slideshow clips adding 1 frame (#3289)
  + fix archive project icon (#3325)
  + fix compilation on armhf (#3345)
  + don't allow creating keyframes for "fixed" filters (#2956)
  + re-enable compilation on KDE < 4.5 (squeeze) (#3319)
  + re-enable Clip menu (fix bug #3347)
  + fix screen recording failure (#3358)
  + fix crash detected with undo/redo (bug #3240)
  + fix crash cutting group on a clip edge (#3312, #3350)
  + fix crash on image sequence (#3331)
  + fix crash in tracks config editor (#3367)
  + fix crash on audiofiles
  + fix crash on opening project file with images
  + fix warnings from static analyzers (cppcheck, krazy)
  + sort source files, easier to understand (for new developpers)
- Update kdenlive-0.9.2-mlt_datadir.patch to
  kdenlive-0.9.10-mlt_datadir.patch
- Update kdenlive-0.9.2-no_avformat.patch to
  kdenlive-0.9.10-no_avformat.patch
* Wed Jul  2 2014 fisiu@opensuse.org
- Build all translations.
* Wed May 21 2014 dap.darkness@gmail.com
- Update to 0.9.8
  + Fades: timeline shortcut now applies to video on clips
    containing video and audio;
  + Copy proxies with 'move project';
  + Remove the MLT processing threads option that never really
    worked;
  + Clean encoding profiles using MLT presets and profiles;
  + Support a custom suffix for FFmpeg binaries (mostly for
    packagers);
  + Make audio align work asynchronously;
  + Add support for JogShuttle on newer systems, make shuttle
    device selection more straightforward, add ProV2 keys;
  + Fix warnings from gcc, cppcheck, clang, scan-build: fixes
    many crashs & leaks;
  + Code cleanup (use const ref, fix includes, mem leaks,
    optimize...);
  + Fix keyframing messed up for some effects;
  + Fix timeline corruption when trying to move clip before 0;
  + Fix crash when closing title widget;
  + Fix thumbnails for image clips in timeline;
  + Fix crash on quick undo/redo (#3240);
  + Fix multithreading (#3186);
  + Fix some problems with transitions keyframes;
  + Fix scopes (#3052).
- Updated kdenlive-0.9.2-mlt_datadir.patch &
  kdenlive-0.9.2-no_avformat.patch.
* Sun Apr  7 2013 hrvoje.senjan@gmail.com
- Update to 0.9.6
  + Fix keyframes when cutting a clip / undoing a clip cut
  + Warn before overwriting .mlt stabilized file
  + Fix monitor confusion (clip monitor sometimes playing timeline)
  + Fix the Mono to Stereo effect UI
  + Fix proxy of playlist having wrong aspect ratio in some locales
  + Fix transition widget not correctly updated when resizing a
    transition
  + Fix DVD chapters broken when using an intro movie
  + Fix error message (No matching profile) poping up in render
    widget when everything was ok
  + Fix clip keyframes not showing on project load
  + Fix bug when moving guide (was not moving to the correct place)
  + Fix project corruption (wrong character) caused by some clip's
    metadata
  + Fix possible crash on track deletion
  + Fix timeline corruption when using spacer tool or overwrite edit
    mode
  + Fix possible crash when editing speed effect
  + Fix transition losing all its properties when moved
  + Fix crash when pressing del when editing animation in title
    widget
  + Fix crash when doing quick clip resize
  + Fix corruption when groups where overlapping
  + Fix corruption when adding a title clip where a transition already
    existed
  + Fix timeline preview corruption with some transitions
* Tue Feb  5 2013 reddwarf@opensuse.org
- Add missing BR: pkgconfig(libv4l2)
* Wed Jan 30 2013 reddwarf@opensuse.org
- Do not recommend recordmydesktop. It's not used any more.
- Update the minimum mlt version
- Reenable V4L support. The legal problem has been fixed.
* Wed Jan 30 2013 nico.kruber@gmail.com
- Update to 0.9.4
  + Rewritten DVD Wizard
  + Improved clip markers
  + Rewritten Screen Capture
  + Support for multiple streams clips
  + Clip analysis feature
  + Stability and Performance improvements
  - 8 features introduced
  - 124 bugs fixed
* Fri Nov 30 2012 reddwarf@opensuse.org
- Make it work with versioned melt binaries
- Add kdenlive-0.9.2-no_avformat.patch to support systems without
  the avformat plugin
* Thu Aug 16 2012 reddwarf@opensuse.org
- Recommend a package with the avformat module
* Mon Aug 13 2012 reddwarf@opensuse.org
- Require libmltX-modules and libmltX-data
* Sun Aug 12 2012 reddwarf@opensuse.org
- Add kdenlive-0.9.2-mlt_datadir.patch to use the correct MLT data
  dir by default
* Fri Jun  1 2012 reddwarf@opensuse.org
- Disable V4L support (bnc#765082). GPL-2.0 only, incompatible
  with GPL-3.0+ parts.
* Thu May 31 2012 reddwarf@opensuse.org
- Update to 0.9.2
  + Fix freeze when reloading previously missing clip
  + Fade effects lost when moving / resizing clip
  + Undoing change in clip crop start breaking clip
  + Make disabling of track effects possible
  + Fix slideshow clips not working
  + Fix crash on composite transition
  + Fix crash when opening stop motion widget
  + Fix rendering of projects created in another locale
  + Fix Firewire capture
* Tue May 15 2012 reddwarf@opensuse.org
- Update to 0.9
  * Improved effects workflow
  * Automatic audio alignment
  * Easy import of online resources
  * Usability improvements
  - Recording can now be monitored through the audio and color
    scopes, audio normalization can analyse audio for better
    results
  - Allow audio only recording
  - Clips can be sorted by date
  - New effects from MLT / frei0r: video stabilizers,
    IIR Blur, etc
  - Offline editing (Backup the project with proxy clips only to
    work on less powerful computers)
  * Read the ChangeLog file for a more complete list of changes
- Add %%icon_theme_cache_post and %%desktop_database_post macros and
  its dependencies as BuildRequires
- Update the BuildRequires
- Updates source tag with new URL
- Recommend genisoimage instead of mkisofs
* Fri May  4 2012 reddwarf@opensuse.org
- Change license from GPL-2.0+ to GPL-2.0 (bnc#760651)
* Mon Feb 27 2012 saschpe@suse.de
- Set SPDX-style license
* Sun Aug 23 2009 reddwarf@opensuse.org
- Initial package
